@@ -7,6 +7,7 @@
 import ttkbootstrap as ttk
 from ttkbootstrap.constants import *
 from ttkbootstrap.dialogs import Messagebox
+from ttkbootstrap.scrolled import ScrolledText
 
 
 def setup_demo(master):
@@ -141,7 +142,7 @@ Namespaces are one honking great idea -- let's do more of those!"""
     nb.add(ttk.Frame(nb), text="Tab 5")
 
     # text widget
-    txt = ttk.Text(master=lframe, height=5, width=50, wrap="none")
+    txt = ScrolledText(master=lframe, height=5, width=50, autohide=True)
     txt.insert(END, ZEN)
     txt.pack(side=LEFT, anchor=NW, pady=5, fill=BOTH, expand=YES)
     lframe_inner = ttk.Frame(lframe)
